@@ -1,10 +1,9 @@
-# $File: //member/autrijus/Encode-HanConvert/lib/Encode/HanConvert.pm $ $Author: autrijus $
-# $Revision: #20 $ $Change: 10742 $ $DateTime: 2004/06/04 07:15:15 $
+# $Id: /mirror/trunk/lib/Encode/HanConvert.pm 34 2006-12-12T11:23:25.221486Z kcwu  $
 
 package Encode::HanConvert;
 use vars qw/$VERSION @EXPORT @EXPORT_OK/;
 
-$VERSION = '0.31';
+$VERSION = '0.32';
 @EXPORT = qw(
     big5_to_gb trad_to_simp big5_to_simp gb_to_trad big5_to_trad gb_to_simp
     gb_to_big5 simp_to_trad simp_to_big5 trad_to_gb trad_to_big5 simp_to_gb
@@ -117,8 +116,8 @@ Encode::HanConvert - Traditional and Simplified Chinese mappings
 
 =head1 VERSION
 
-This document describes version 0.29 of Encode::HanConvert, released
-June 4, 2004.
+This document describes version 0.32 of Encode::HanConvert, released
+Dec 12, 2006.
 
 =head1 SYNOPSIS
 
@@ -217,16 +216,16 @@ mapping with B<Big5> and B<GBK> encodings.
 
 Also, L<Encode::HanConvert> loads up much faster:
 
-    0.148u 0.046s 0:00.19 94.7% # Encode::HanConvert
-    1.192u 0.046s 0:01.26 97.6% # Encode::HanConvert::Perl
-    7.096u 0.015s 0:07.23 98.2% # Lingua::ZH::HanConvert (v0.12)
+    0.04 real 0.03 user 0.01 sys # Encode::HanConvert
+    0.19 real 0.18 user 0.00 sys # Encode::HanConvert::Perl
+    1.68 real 1.66 user 0.01 sys # Lingua::ZH::HanConvert (v0.12)
 
-The difference in actual conversion is much more significant. Use 32k
+The difference in actual conversion is much more significant. Use 5mb
 text of trad => simp as an example:
 
-    0.082u 0.031s 0:00.12 91.6% # iconv | b2g | iconv
-    0.263u 0.038s 0:00.30 96.6% # Encode::HanConvert
-   23.715u 0.054s 0:24.51 96.9% # Lingua::ZH::HanConvert (v0.12)
+    0.77 real  0.25 user 0.00 sys # iconv | b2g | iconv
+    0.64 real  0.59 user 0.04 sys # Encode::HanConvert b2g.pl -u
+   13.79 real 13.69 user 0.02 sys # Lingua::ZH::HanConvert trad2simp (v0.12)
 
 The C<b2g> above refers to Yeung and Lee's I<HanZi Converter>, a C-based
 program that maps big5 to gb2312 and back; C<iconv> refers to GNU
@@ -261,8 +260,9 @@ The conversion table used in this module comes from various sources,
 including B<Lingua::ZH::HanConvert> by David Chan, B<hc> by Ricky
 Yeung & Fung F. Lee, and B<Doggy Chinese Big5-GB Conversion Master>
 from Doggy Digital Creative Inc. (L<http://www.miniasp.com/>), Rei-Li
-Chen (rexchen), as well as mappings used in Microsoft Word 2000, Far
-East edition.
+Chen (rexchen), Unicode consortium's Unicode Character Database
+(L<http://www.unicode.org/ucd/>), as well as mappings used in Microsoft Word
+2000, Far East edition.
 
 The F<*.ucm> files are checked against test files generated by GNU
 libiconv with kind permission from Bruno Haible.
@@ -279,11 +279,13 @@ The L<b2g.pl> and L<g2b.pl> utilities installed with this module.
 
 =head1 AUTHORS
 
-Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>
+Currently maintained by Kuang-che Wu E<lt>kcwu@csie.orgE<gt>.  Orignal author:
+Audreyt Tang E<lt>cpan@audreyt.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2002, 2003, 2004 by Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>.
+Copyright 2002, 2003, 2004 by Audreyt Tang E<lt>cpan@audreyt.orgE<gt>.
+Copyright 2006 by Kuang-che Wu E<lt>kcwu@csie.orgE<gt>.
 
 This program is free software; you can redistribute it and/or 
 modify it under the same terms as Perl itself.
